@@ -16,6 +16,7 @@ from sqlalchemy import Integer, String, Boolean, DateTime
 from geoalchemy2 import Geometry
 from geoalchemy2.shape import to_shape, from_shape
 from sqlalchemy.orm import relationship, backref, object_session, Session
+from sqlalchemy.dialects.postgresql import TIMESTAMP
 
 import nltk
 import pandas as pd
@@ -187,7 +188,7 @@ class Entry(Base):
     embargo = Column(Boolean, default=False, nullable=False)
     embargo_end = Column(DateTime, default=get_embargo_end)
 
-    publication = Column(DateTime, default=dt.utcnow)
+    publication = Column(TIMESTAMP(precision=0), default=dt.utcnow)
     lastUpdate = Column(DateTime, default=dt.utcnow, onupdate=dt.utcnow)
 
     # relationships
@@ -478,7 +479,7 @@ class Entry(Base):
         return [kw.keyword.path() for kw in self.keywords]
 
     def plain_keywords_dict(self):
-        return [kw.keyword.as_dict() for kw in self.keywords]
+        return [kw.keyword.to_dict() for kw in self.keywords]
 
     def keywords_dict(self):
         return [
