@@ -61,7 +61,7 @@ from metacatalog.util.dict_functions import flatten
 
 
 class ImmutableResultSet:
-    def __init__(self, instance: Union[Entry, EntryGroup]):
+    def __init__(self, instance: Union[Entry, EntryGroup, 'ImmutableResultSet']):
         """
         ImmutableResultSet for the given EntryGroup or Entry.
         
@@ -81,6 +81,10 @@ class ImmutableResultSet:
             group = instance
             members = [ImmutableResultSet.expand_entry(e, group) for e in instance.entries]
 
+        elif isinstance(instance, ImmutableResultSet):
+            group = instance.group
+            members = instance._members
+
         # set attributes
         self.group = group
         self._members = ImmutableResultSet.entry_set(members)
@@ -111,9 +115,9 @@ class ImmutableResultSet:
             idx = type_names.index('Composite')
             return groups[idx]
         
-        # if 'Split dataset' in type_names:
-        #     idx = type_names.index('Split dataset')
-        #     return groups[idx]
+        if 'Split dataset' in type_names:
+            idx = type_names.index('Split dataset')
+            return groups[idx]
         
         return None
 
@@ -135,7 +139,7 @@ class ImmutableResultSet:
                 if base_group is not None and base_group.id == g.id:
                     entries.extend([entry])
                 else:
-                    entries.extend([ImmutableResultSet(g)])
+                    entries.extend(ImmutableResultSet(g)._members)
             
             # composites expand completely
             elif g.type.name == 'Composite':
@@ -255,6 +259,11 @@ class ImmutableResultSet:
     def uuids(self):
         """
         Return all uuids that form this result set
+
+        .. versionchanged:: 0.6.8
+            If a member in in _members is an ImmutableResultSet, call this
+            method recursively
+
         """
         # get the group uuid
         uuids = [self.group.uuid] if self.group is not None else []
@@ -262,6 +271,11 @@ class ImmutableResultSet:
         # expand member uuids
         uuids.extend([e.uuid for e in self._members if hasattr(e, 'uuid')])
 
+        # if member is a ImmutableResultSet again, call this method recursicely
+        for m in self._members:
+            if hasattr(m, 'uuids'):
+                uuids.extend(m.uuids)
+
         return uuids
 
     @property
@@ -318,10 +332,16 @@ class ImmutableResultSet:
         # build the output dictionary
         return {key: self.get(key) for key in keys}
 
-    def to_dict(self):
+    def to_dict(self, orient: str = 'dict'):
         """
         Generate a full dictionary output of this result set.
 
+        .. versionchanged:: 0.6.8
+            Parameter `orient` added. The default value is `'dict'`, which returns
+            a dictionary with unique keys.
+            The value `'uuids'` will give the dictionary with uuids as keys, this
+            should make it easier to i.e. loop over the uuids / entities of an
+            ImmutableResultSet.
         """
         # first get a list of all available keys
         keys = []
@@ -334,7 +354,12 @@ class ImmutableResultSet:
         keys = set(keys)
 
         # build the output dictionary
-        return {key: self.get(key) for key in keys}
+        if orient.lower() == 'dict':
+            return {key: self.get(key) for key in keys}
+        elif orient.lower() == 'uuids':
+            raise NotImplementedError
+        else:
+            raise AttributeError(f"orient = '{orient}' is not supported. Use one of ['dict', 'uuids']")
 
     def get_data(self, verbose=False, merge=False, **kwargs) -> dict:
         """
@@ -404,13 +429,16 @@ class ImmutableResultSet:
                         all_data = pd.merge(all_data, dat, left_index=True, right_index=True, how='outer')
                     else:
                         unmerged.update({checksum: dat})
+            
             # Split dataset: concat everything that is a DataFrame
             elif self.group is not None and self.group.type.name == 'Split dataset':
                 for checksum, dat in data.items():
                     if isinstance(dat, pd.DataFrame):
+                        # TODO: update with better pandas function!
                         all_data = pd.concat([all_data, dat])
                     else:
                         unmerged.update({checksum: dat})
+            
             # other EntryGroup types?
             else:
                 for checksum, dat in data.items():
